@@ -2,5 +2,5 @@
 #define BREAKPOINT_LENGTH 1
 #define DECR_PC_AFTER_BREAK 1
 
-#define FILEFORMAT_CHECK	1
-#define ELFSIZE	64
+#define LT_ELFCLASS	ELFCLASS64
+#define LT_ELF_MACHINE	EM_X86_64
